@@ -6,7 +6,6 @@ from gpt_index.indices.keyword_table.rake_base import GPTRAKEKeywordTableIndex
 from gpt_index.indices.keyword_table.simple_base import GPTSimpleKeywordTableIndex
 from gpt_index.indices.list.base import GPTListIndex
 from gpt_index.indices.tree.base import GPTTreeIndex
-from gpt_index.indices.vector_store.faiss import GPTFaissIndex
 
 __all__ = [
     "GPTKeywordTableIndex",
@@ -14,5 +13,4 @@ __all__ = [
     "GPTRAKEKeywordTableIndex",
     "GPTListIndex",
     "GPTTreeIndex",
-    "GPTFaissIndex",
 ]
