@@ -1,15 +1,15 @@
 """Embedding utils for queries."""
 
-from typing import Dict, List, Optional, Tuple
+from typing import Callable, Dict, List, Optional, Tuple
 
 from gpt_index.data_structs.data_structs import Node
-from gpt_index.embeddings.openai import BaseEmbedding
+from gpt_index.embeddings.base import similarity as default_similarity_fn
 
 
 def get_top_k_embeddings(
-    embed_model: BaseEmbedding,
     query_embedding: List[float],
     embeddings: List[List[float]],
+    similarity_fn: Optional[Callable[..., float]] = None,
     similarity_top_k: Optional[int] = None,
     embedding_ids: Optional[List] = None,
 ) -> Tuple[List[float], List]:
@@ -17,9 +17,11 @@ def get_top_k_embeddings(
     if embedding_ids is None:
         embedding_ids = [i for i in range(len(embeddings))]
 
+    similarity_fn = similarity_fn or default_similarity_fn
+
     similarities = []
     for emb in embeddings:
-        similarity = embed_model.similarity(query_embedding, emb)
+        similarity = similarity_fn(query_embedding, emb)
         similarities.append(similarity)
 
     sorted_tups = sorted(
